@@ -30,7 +30,7 @@ class API:
 
     def _init_driver(self, WEB_DRIVER_PATH):
         """
-        This method is to initialize the driver. A new driver is initialized for all methods.
+        This method is to initialize the driver. A new driver is initialized for all methods.        
         There are some default options given to the driver, to make it ignore some certificate errors,
         that is to ignore the pop up box which comes when we use an uncertified webpage. And the driver is made a headless, so that it could be faster.
         This method is only invoked by the _parse().
@@ -50,7 +50,7 @@ class API:
         options = webdriver.ChromeOptions()
         options.add_argument("--ignore-certificate-errors")
         options.add_argument("--incognito")
-        options.add_argument("--headless")
+        # options.add_argument("--headless")
         driver = webdriver.Chrome(WEB_DRIVER_PATH, options=options)
 
         return driver
@@ -59,7 +59,7 @@ class API:
         """
         This method invokes the _inti_driver and gets the HTML sourse of the page. Using Beautiful Soup the HTML is parsed and returned.
         If the default SCROLL_PAUSE_TIME is None, if then then page won't get scrolled. In some cases, the contents are loaded only when the page is loaded, then the SCROLL_PAUSE_TIME should be given some floating point value.
-        The limit is to limit the number of return object, because some of the methods couold lead to the web page, where it is like an infinite scroll, so to save time, limit is given.
+        The limit is to limit the number of return object, because some of the methods couold lead to the web page, where it is like an infinite scroll, so to save time, limit is given. 
         The limit query is implicitly generatd for all the methods, which could give limit.
 
         Parameters
@@ -77,6 +77,7 @@ class API:
 
         """
         driver = self._init_driver(self.DRIVER_PATH)
+        driver.implicitly_wait(SCROLL_PAUSE_TIME)
         driver.get(url)
 
         if SCROLL_PAUSE_TIME or limit is not None:
@@ -118,6 +119,7 @@ class API:
         """
 
         last_height = driver.execute_script("return document.body.scrollHeight")
+        sleep(SCROLL_PAUSE_TIME)
         while True:
             driver.execute_script("window.scrollTo(0, document.body.scrollHeight);")
             sleep(SCROLL_PAUSE_TIME)
@@ -136,7 +138,7 @@ class API:
                             limit_query[1]["search"], class_=limit_query[0]["class"]
                         )
                     )
-                    <= limit
+                    >= limit
                 ):
                     return soup
             new_height = driver.execute_script("return document.body.scrollHeight")
@@ -150,7 +152,7 @@ class API:
 
         stock_name      : The name of the stock
 
-        stock_url       : The detailed view of the stock, from which we can get the stock info.
+        stock_url       : The detailed view of the stock, from which we can get the stock info. 
                           NOTE: The method get_stock_info() should use the url generated by this method.
 
         opinion         : Number of opinions about the stock
@@ -164,14 +166,14 @@ class API:
 
         Returns
         -------
-        to_return : TYPE list
+        to_return : TYPE list 
             DESCRIPTION. list of following stock with their respective URL of the detailed view
 
         """
         to_return = list()
 
         division = soup.find("div", class_="clearfix ptf20")
-        if division is None:
+        if division is not None:
             name = division.findAll("a", class_="txt18gry", limit=limit)
             url = division.findAll("a", class_="anchbtmde", limit=limit)
             opinion = list()
@@ -291,7 +293,6 @@ class API:
         ]
 
         for i, j in zip(keys, values):
-            # print(j)
             to_return[i] = int(j.getText().split()[2])
 
         ul = soup.find("ul", class_="blul")
@@ -417,11 +418,11 @@ class API:
         following_boarders_limit : TYPE integer, optional
             DESCRIPTION. The default is None. To limit the details of following boarders.
         boarders_following_limit : TYPE integer, optional
-            DESCRIPTION. The default is None. To limit the details of boarders following.
+            DESCRIPTION. The default is None. To limit the details of boarders following. 
         post_limit : TYPE integer, optional
             DESCRIPTION. The default is None. To limit the details of post limit.
         limit_query : TYPE list of dict, optional
-            DESCRIPTION. The default is None. The constraint to be checked when the limit is given.
+            DESCRIPTION. The default is None. The constraint to be checked when the limit is given. 
             This is not needed to give explicitly.
             It is addressed implicitly for all the functions.
 
@@ -765,7 +766,7 @@ class API:
 
     def get_stock_in_the_news(self, save_as_json=False, file_path=""):
         """
-        This method gets the stock in the news.
+        This method gets the stock in the news.        
 
         Parameters
         ----------
@@ -796,4 +797,4 @@ class API:
         if save_as_json == True:
             self.save_json(to_return, "stock_news.json", file_path)
 
-        return to_return
\ No newline at end of file
+        return to_return
